@@ -6,36 +6,15 @@ import shutil
 import sys
 import termios
 import threading
+from prompt_toolkit import prompt
+from prompt_toolkit.lexers import Lexer
 
 import cuitools.subp
 
 
 def reset():
     terminal_size = shutil.get_terminal_size()
-    print("\033[1;1H"+"\033[2K\n"*(terminal_size[1]),end="")
-
-
-def Input(text, normal=False, textcolor="\033[38;5;10m", dotcolor="\033[38;5;7m", usercolor="\033[38;5;12m", dot=True):
-    """ \033[0m	指定をリセットし未指定状態に戻す（0は省略可）
-        \033[1m	太字
-        \033[2m	薄く表示
-        \033[3m	イタリック
-        \033[4m	アンダーライン
-        \033[5m	ブリンク
-        \033[6m	高速ブリンク
-        \033[7m	文字色と背景色の反転
-        \033[8m	表示を隠す（コピペ可能）
-        \033[9m	取り消し
-        """
-    if not normal:
-        normal = "\033[1m"
-    else:
-        normal = "\033[0m"
-    if dot:
-        inp = input(normal + textcolor + text + dotcolor + ":\033[0m" + usercolor)
-    else:
-        inp = input(normal + textcolor + text + usercolor)
-    return inp
+    print("\033[1;1H" + "\033[2K\n" * (terminal_size[1]), end="")
 
 
 def Key():
